#!/usr/local/bin/perl -w
#
# Build lists.sgml, projects.sgml, resources.sgml, which contain links to
# the mailing lists, projects, and resources respectively.
#
# $Id$

use strict;

my @dirs  = ();				     # Directories to process
my $dir   = "";				     # Directory being processed
my %lists = ();				     # Lists hash (dir => name)
my $list  = "";				     # Current list

# Standard HTML prologue for each of the three files
my $HTMLheader =<<'EOM'
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" [
<!ENTITY email "nik">
<!ENTITY title "%s">
<!ENTITY %% includes SYSTEM "../includes.sgml"> %%includes;
]>

<html>
  &header;

EOM
  ;
my $HTMLfooter =<<'EOM'; 
    &footer;
  </body>
</html>
EOM
  ;

# Get a list of all directories in the current directory
opendir(D, ".") or die "Could not open current directory: $!\n";
@dirs = grep { /[^\.]/ && -d $_ } readdir(D);

# Pull out the description for each list
foreach $dir (@dirs) {
    if(! -f "$dir/list.ent") {
	warn "No list.ent found in $dir\n";
	next;
    }

    if(! -f "$dir/about.sgml") {
	warn "No about.sgml found in $dir\n";
	next;
    }

    # Open list.ent, pull out the list's title
    open(F, "$dir/list.ent") or die "Could not open $dir/list.ent: $!";
    while(<F>) {
	if($_ =~ /list-title\s+\"([^\"]+)\"/) {
	    $lists{$dir}{'title'} = $1;
	    next;
	}

	if($_ =~ /list-desc\s+\"([^\"]+)\"/) {
	    $lists{$dir}{'desc'} = $1;
	    next;
	}
    }
}

# ------------------------------------------------------------------------     
# lists.sgml
# ------------------------------------------------------------------------
open(F, ">lists.sgml") or die "Could not open lists.sgml: $!\n";

printf F $HTMLheader, "Mailing Lists";

# Information about each list
foreach $list (sort keys %lists) {
    print F <<EOM;
    <h3><font color=\"#990000\">$lists{$list}{'desc'}</font> (<small><a href="$list/index.html">More information...</a></small>)</h3>

    <blockquote>
EOM
  ;
    print F do { local @ARGV = "$list/about.sgml"; <> };

    print F "    </blockquote>\n\n";
}

print F $HTMLfooter;

# ------------------------------------------------------------------------
# projects.sgml
# ------------------------------------------------------------------------
open(F, ">projects.sgml") or die "Could not open projects.sgml: $!\n";
printf F $HTMLheader, "Projects";

# Pull in the projects.sgml file for each list in turn, if it exists
foreach $list (sort keys %lists) {
    if(-f "$list/projects.sgml") {
	print F qq{    <h3><font color="#990000">$lists{$list}{'desc'}</font> <small>(Mailing list: <a href="$list/index.html">$lists{$list}{'title'}</a>)</small></h3>\n\n};

	print F do { local @ARGV = "$list/projects.sgml"; <> };
    }
}

# ------------------------------------------------------------------------
# resources.sgml
# ------------------------------------------------------------------------
open(F, ">resources.sgml") or die "Could not open projects.sgml: $!\n";
printf F $HTMLheader, "Resources";

# Pull in the projects.sgml file for each list in turn, if it exists
foreach $list (sort keys %lists) {
    if(-f "$list/resources.sgml") {
	print F qq{    <h3><font color="#990000">$lists{$list}{'desc'}</font> <small>(Mailing list: <a href="$list/index.html">$lists{$list}{'title'}</a>)</small></h3>\n\n};

	print F do { local @ARGV = "$list/resources.sgml"; <> };
    }
}
